@@ -1,14 +1,19 @@
 # tree.py: classes to handle and display the structure of a wxGlade app
-# $Id: tree.py,v 1.42 2004/10/24 16:12:50 agriggio Exp $
+# $Id: tree.py,v 1.56 2007/08/07 12:13:44 agriggio Exp $
 # 
-# Copyright (c) 2002-2004 Alberto Griggio <agriggio@users.sourceforge.net>
+# Copyright (c) 2002-2007 Alberto Griggio <agriggio@users.sourceforge.net>
 # License: MIT (see license.txt)
 # THIS PROGRAM COMES WITH NO WARRANTY
 
-from wxPython.wx import *
+#from wxPython.wx import *
+import wx
 from xml.sax.saxutils import quoteattr
 import misc, common, os.path
 
+try: set
+except NameError: from sets import Set as set
+
+
 class Tree:
     """\
     A class to represent a hierarchy of widgets.
@@ -28,9 +33,9 @@ class Tree:
                 if node.widget is not None:
                     # replace the just destroyed notebook with an empty window
                     pw = node.widget.property_window
-                    pw.SetTitle('Properties - <>')
+                    pw.SetTitle(_('Properties - <>'))
                     if Tree.Node.__empty_win is None:
-                        Tree.Node.__empty_win = wxWindow(pw, -1)
+                        Tree.Node.__empty_win = wx.Window(pw, -1)
                     pw.GetSizer().GetChildren()[0].SetWindow(
                         Tree.Node.__empty_win)
                     #wxNotebook(node.widget.property_window, -1))
@@ -45,7 +50,7 @@ class Tree:
             try: return self.widget.name
             except AttributeError: return repr(self.widget)
 
-        def write(self, outfile, tabs):
+        def write(self, outfile, tabs, class_names=None):
             """\
             Writes the xml code for the widget to the given output file
             """
@@ -54,23 +59,46 @@ class Tree:
             assert self.widget is not None
             w = self.widget
             classname = getattr(w, '_classname', w.__class__.__name__)
-            fwrite('    ' * tabs + '<object class=%s name=%s base=%s>\n'
+            # ALB 2005-11-19: to disable custom class code generation
+            # (for panels...)
+            no_custom = ""
+            if getattr(w, 'no_custom_class', False):
+                no_custom = ' no_custom_class="1"'
+            fwrite('    ' * tabs + '<object class=%s name=%s base=%s%s>\n'
                    % (quoteattr(w.klass), quoteattr(w.name),
-                      quoteattr(classname)))
+                      quoteattr(classname), no_custom))
             for p in w.properties:
                 w.properties[p].write(outfile, tabs+1)
 
+            if class_names is not None:
+                class_names.add(w.klass)
+
             if isinstance(w, edit_sizers.SizerBase):
-                if self.children is not None:
-                    for c in self.children:
+                maxpos = len(w.children)
+                children = self.children is not None and self.children or []
+                tmp = {}
+                for c in children:
+                    tmp[c.widget.pos] = c
+                children = []
+                class SlotNode:
+                    def write(self, outfile, tabs):
+                        fwrite('    ' * tabs + '<object class="sizerslot" />\n')
+                for i in range(1, maxpos):
+                    children.append(tmp.get(i, SlotNode()))
+                #if self.children is not None:
+                #    for c in self.children:
+                for c in children:
+                    if hasattr(c, 'widget'):
                         fwrite('    ' * (tabs+1) +
                                '<object class="sizeritem">\n')
                         sp = c.widget.sizer_properties
                         for p in sp: sp[p].write(outfile, tabs+2)
-                        c.write(outfile, tabs+2)
+                        c.write(outfile, tabs+2, class_names)
                         fwrite('    ' * (tabs+1) + '</object>\n')
+                    else:
+                        c.write(outfile, tabs+1)
             elif self.children is not None:
-                for c in self.children: c.write(outfile, tabs+1)
+                for c in self.children: c.write(outfile, tabs+1, class_names)
             fwrite('    ' * tabs + '</object>\n')
 
     # end of class Node
@@ -84,7 +112,7 @@ class Tree:
                         # itself a dictionary, one for each toplevel widget...
 
     def _find_toplevel(self, node):
-        assert node is not None, "None node in _find_toplevel"
+        assert node is not None, _("None node in _find_toplevel")
         if node.parent is self.root:
             return node.parent
         while node.parent is not self.root:
@@ -113,7 +141,9 @@ class Tree:
         child.parent = parent
         self.current = child
         #self.names[str(child.widget.name)] = 1
-        self.names.setdefault(parent, {})[str(child.widget.name)] = 1
+        #self.names.setdefault(parent, {})[str(child.widget.name)] = 1
+        self.names.setdefault(self._find_toplevel(child), {})[
+            str(child.widget.name)] = 1
         if parent is self.root and \
                getattr(child.widget.__class__, '_is_toplevel', False):
             self.app.add_top_window(child.widget.name)
@@ -126,7 +156,9 @@ class Tree:
         child.parent = parent
         self.current = child
         #self.names[str(child.widget.name)] = 1
-        self.names.setdefault(parent, {})[str(child.widget.name)] = 1
+        #self.names.setdefault(parent, {})[str(child.widget.name)] = 1
+        self.names.setdefault(self._find_toplevel(child), {})[
+            str(child.widget.name)] = 1
         if parent is self.root:
             self.app.add_top_window(child.widget.name)
 
@@ -161,7 +193,7 @@ class Tree:
         import common
         outfile.write('<?xml version="1.0"?>\n<!-- generated by wxGlade %s ' \
                       'on %s -->\n\n' % (common.version, asctime()))
-        outpath = self.app.output_path.strip()
+        outpath = os.path.expanduser(self.app.output_path.strip())
         name = self.app.get_name()
         klass = self.app.get_class()
         option = str(self.app.codegen_opt)
@@ -169,22 +201,30 @@ class Tree:
         language = self.app.get_language()
         encoding = self.app.get_encoding()
         use_gettext = str(int(self.app.use_gettext))
+        is_template = str(int(self.app.is_template))
         overwrite = str(int(self.app.overwrite))
         # ALB 2004-01-18
-        use_new_namespace = str(int(self.app.get_use_new_namespace()))
+        #use_new_namespace = str(int(self.app.get_use_new_namespace()))
+        use_new_namespace = str(int(not self.app.get_use_old_namespace()))
+        # ALB 2004-12-05
+        for_version = str(self.app.for_version)
         outfile.write('<application path=%s name=%s class=%s option=%s ' \
                       'language=%s top_window=%s encoding=%s ' \
                       'use_gettext=%s overwrite=%s '
-                      'use_new_namespace=%s>\n' \
-                      % tuple(map(quoteattr,
-                                  [outpath, name, klass, option, language,
-                                   top_window, encoding, use_gettext,
-                                   overwrite, use_new_namespace]))
-                      )
+                      'use_new_namespace=%s for_version=%s is_template=%s>\n' \
+                      % tuple([quoteattr(common._encode_to_xml(i)) for i in 
+                               (outpath, name, klass, option, language,
+                                top_window, encoding, use_gettext,
+                                overwrite, use_new_namespace, for_version,
+                                is_template)]))
+        if self.app.is_template and getattr(self.app, 'template_data', None):
+            self.app.template_data.write(outfile, tabs+1)
+        class_names = set()
         if self.root.children is not None:
             for c in self.root.children:
-                c.write(outfile, tabs+1)
+                c.write(outfile, tabs+1, class_names)
         outfile.write('</application>\n')
+        return class_names
 
     def change_node(self, node, widget):
         """\
@@ -211,27 +251,33 @@ class Tree:
 # end of class Tree
 
 
-class WidgetTree(wxTreeCtrl, Tree):
+class WidgetTree(wx.TreeCtrl, Tree):
     """\
     Tree with the ability to display the hierarchy of widgets
     """
     images = {} # dictionary of icons of the widgets displayed
     def __init__(self, parent, application):
-        id = wxNewId()
-        wxTreeCtrl.__init__(self, parent, id, style=wxTR_DEFAULT_STYLE |
-                            wxTR_HAS_VARIABLE_ROW_HEIGHT)
+        id = wx.NewId()
+        style = wx.TR_DEFAULT_STYLE|wx.TR_HAS_VARIABLE_ROW_HEIGHT
+        if wx.Platform == '__WXGTK__':
+            style |= wx.TR_NO_LINES|wx.TR_FULL_ROW_HIGHLIGHT
+        elif wx.Platform == '__WXMAC__':
+            style &= ~wx.TR_ROW_LINES
+        wx.TreeCtrl.__init__(self, parent, id, style=style)
         root_node = Tree.Node(application)
         self.cur_widget = None # reference to the selected widget
         Tree.__init__(self, root_node, application)
-        image_list = wxImageList(21, 21)
-        image_list.Add(wxBitmap(os.path.join(common.wxglade_path,
+        image_list = wx.ImageList(21, 21)
+        image_list.Add(wx.Bitmap(os.path.join(common.wxglade_path,
                                              'icons/application.xpm'),
-                                wxBITMAP_TYPE_XPM))
+                                wx.BITMAP_TYPE_XPM))
         for w in WidgetTree.images:
-            WidgetTree.images[w] = image_list.Add(wxBitmap(
-                WidgetTree.images[w], wxBITMAP_TYPE_XPM))
+##             WidgetTree.images[w] = image_list.Add(wx.Bitmap(
+##                 WidgetTree.images[w], wx.BITMAP_TYPE_XPM))
+            WidgetTree.images[w] = image_list.Add(
+                misc.get_xpm_bitmap(WidgetTree.images[w]))
         self.AssignImageList(image_list)
-        root_node.item = self.AddRoot('Application', 0)
+        root_node.item = self.AddRoot(_('Application'), 0)
         self.SetPyData(root_node.item, root_node)
         self.skip_select = 0 # necessary to avoid an infinite loop on win32, as
                              # SelectItem fires an EVT_TREE_SEL_CHANGED event
@@ -243,22 +289,22 @@ class WidgetTree(wxTreeCtrl, Tree):
         self._show_menu = misc.wxGladePopupMenu('widget') # popup menu to
                                                           # show toplevel
                                                           # widgets
-        SHOW_ID = wxNewId()
-        self._show_menu.Append(SHOW_ID, 'Show')
-        EVT_TREE_SEL_CHANGED(self, id, self.on_change_selection)
-        EVT_RIGHT_DOWN(self, self.popup_menu)
-        EVT_LEFT_DCLICK(self, self.show_toplevel)
-        EVT_MENU(self, SHOW_ID, self.show_toplevel)
+        SHOW_ID = wx.NewId()
+        self._show_menu.Append(SHOW_ID, _('Show'))
+        wx.EVT_TREE_SEL_CHANGED(self, id, self.on_change_selection)
+        wx.EVT_RIGHT_DOWN(self, self.popup_menu)
+        wx.EVT_LEFT_DCLICK(self, self.show_toplevel)
+        wx.EVT_MENU(self, SHOW_ID, self.show_toplevel)
         def on_key_down(event):
             evt_flags = 0
-            if event.ControlDown(): evt_flags = wxACCEL_CTRL
+            if event.ControlDown(): evt_flags = wx.ACCEL_CTRL
             evt_key = event.GetKeyCode()
             for flags, key, function in misc.accel_table:
                 if evt_flags == flags and evt_key == key:
-                    wxCallAfter(function)
+                    wx.CallAfter(function)
                     break
             event.Skip()
-        EVT_KEY_DOWN(self, on_key_down)
+        wx.EVT_KEY_DOWN(self, on_key_down)
 
     def _build_label(self, node):
         s = node.widget.name
@@ -283,6 +329,7 @@ class WidgetTree(wxTreeCtrl, Tree):
             self.Expand(parent.item)
             self.select_item(child)
         child.widget.show_properties()
+        self.app.check_codegen(child.widget)
 
     def insert(self, child, parent, pos, image=None):
         """\
@@ -316,6 +363,7 @@ class WidgetTree(wxTreeCtrl, Tree):
             self.Expand(parent.item)
             self.select_item(child)
         child.widget.show_properties()
+        self.app.check_codegen(child.widget)
 
     def remove(self, node=None):
         self.app.saved = False # update the status of the app
@@ -327,7 +375,7 @@ class WidgetTree(wxTreeCtrl, Tree):
             except: self.SelectItem(self.GetRootItem())
             self.Delete(node.item)
         else:
-            wxTreeCtrl.Destroy(self)
+            wx.TreeCtrl.Destroy(self)
 
     def clear(self):
         self.app.reset()
@@ -412,7 +460,7 @@ class WidgetTree(wxTreeCtrl, Tree):
     def set_title(self, value):
         if value is None: value = ""
         self.title = value
-        try: self.GetParent().SetTitle('wxGlade: Tree %s' % value)
+        try: self.GetParent().SetTitle(_('wxGlade: Tree %s') % value)
         except: pass
 
     def get_title(self):
@@ -424,22 +472,24 @@ class WidgetTree(wxTreeCtrl, Tree):
         Shows the widget of the given node and all its children
         """
         if toplevel:
+            if not wx.IsBusy():
+                wx.BeginBusyCursor()
             if not node.widget.widget:
                 node.widget.create_widget()
                 node.widget.finish_widget_creation()
             if node.children:
                 for c in node.children: self.show_widget(c)
-##             # set the best size for the widget (if no one is given) before
-##             # showing it
-##             if not node.widget.properties['size'].is_active() and \
-##                    node.widget.sizer:
-##                 node.widget.sizer.fit_parent() #node.widget)
             node.widget.post_load()
             node.widget.show_widget(True)
             node.widget.show_properties()
             node.widget.widget.Raise()
-
-
+            # set the best size for the widget (if no one is given)
+            props = node.widget.properties
+            if 'size' in props and not props['size'].is_active() and \
+                   node.widget.sizer:
+                node.widget.sizer.fit_parent()
+            if wx.IsBusy():
+                wx.EndBusyCursor()
         else:
             import edit_sizers
             def show_rec(node):
@@ -452,8 +502,7 @@ class WidgetTree(wxTreeCtrl, Tree):
 ##                 if isinstance(w, edit_sizers.SizerBase): return
 ##                 elif not w.properties['size'].is_active() and \
 ##                          w.sizer and w.sizer.toplevel:
-##                     w.sizer.fit_parent()
-                    
+##                     w.sizer.fit_parent()                    
             show_rec(node)
 
     def show_toplevel(self, event):
@@ -490,8 +539,8 @@ class WidgetTree(wxTreeCtrl, Tree):
         If toplevels_only is True, scans only root's children
         """
         item, flags = self.HitTest((x, y))
-        if item and flags & (wxTREE_HITTEST_ONITEMLABEL |
-                             wxTREE_HITTEST_ONITEMICON):
+        if item and flags & (wx.TREE_HITTEST_ONITEMLABEL |
+                             wx.TREE_HITTEST_ONITEMICON):
             node = self.GetPyData(item)
             if not toplevels_only or node.parent is self.root:
                 return node
@@ -535,5 +584,79 @@ class WidgetTree(wxTreeCtrl, Tree):
         self.Delete(old_item)
         self.Thaw()
 
+    def get_selected_path(self):
+        """\
+        returns a list of widget names, from the toplevel to the selected one
+        Example:
+        ['frame_1', 'sizer_1', 'panel_1', 'sizer_2', 'button_1']
+        if button_1 is the currently selected widget.
+        """
+        from edit_sizers import SizerBase
+        ret = []
+        w = self.cur_widget
+        oldw = None
+        while w is not None:
+            oldw = w
+            ret.append(w.name)
+            sizer = getattr(w, 'sizer', None)
+            if getattr(w, 'parent', "") is None:
+                w = w.parent
+            elif sizer is not None and not sizer.is_virtual():
+                w = sizer
+            else:
+                if isinstance(w, SizerBase):
+                    w = w.window
+                else:
+                    w = w.parent
+        ret.reverse()
+        # ALB 2007-08-28: remember also the position of the toplevel window in
+        # the selected path
+        if oldw is not None:
+            assert oldw.widget
+            pos = misc.get_toplevel_parent(oldw.widget).GetPosition()
+            ret[0] = (ret[0], pos)
+        return ret
+
+    def select_path(self, path):
+        """\
+        sets the selected widget from a path_list, which should be in the
+        form returned by get_selected_path
+        """
+        index = 0
+        item, cookie = self._get_first_child(self.GetRootItem())
+        itemok = None
+        parent = None
+        pos = None
+        while item.Ok() and index < len(path):
+            widget = self.GetPyData(item).widget
+            name = path[index]
+            if index == 0 and type(name) == type(()):
+                name, pos = name
+            if misc.streq(widget.name, name):
+                #print 'OK:', widget.name
+                #self.EnsureVisible(item)
+                itemok = item
+                if parent is None:
+                    parent = self.GetPyData(itemok)
+                self.cur_widget = widget
+                item, cookie = self._get_first_child(item)
+                index += 1
+            else:
+                #print 'NO:', widget.name
+                item = self.GetNextSibling(item)
+        if itemok is not None:
+            node = self.GetPyData(itemok)
+            if parent is not None:
+                self.show_widget(parent, True)
+                if pos is not None:
+                    misc.get_toplevel_parent(parent.widget).SetPosition(pos)
+            self.select_item(node)
+        
+    def _get_first_child(self, item):
+        if misc.check_wx_version(2, 5):
+            return self.GetFirstChild(item)
+        else:
+            return self.GetFirstChild(item, 1)
+        
 # end of class WidgetTree
 
