@@ -1,12 +1,12 @@
 # Grid.py: wxGrid objects
-# $Id: grid.py,v 1.27 2004/09/17 13:09:53 agriggio Exp $
+# $Id: grid.py,v 1.33 2007/03/27 07:01:58 agriggio Exp $
 #
-# Copyright (c) 2002-2004 Alberto Griggio <agriggio@users.sourceforge.net>
+# Copyright (c) 2002-2007 Alberto Griggio <agriggio@users.sourceforge.net>
 # License: MIT (see license.txt)
 # THIS PROGRAM COMES WITH NO WARRANTY
 
-from wxPython.wx import *
-from wxPython.grid import *
+import wx
+from wx.grid import *
 import common, misc
 from edit_windows import ManagedBase
 from tree import Tree
@@ -81,6 +81,26 @@ class ColsHandler:
 
 
 class EditGrid(ManagedBase):
+
+    events = [
+        'EVT_GRID_CMD_CELL_LEFT_CLICK',
+        'EVT_GRID_CMD_CELL_RIGHT_CLICK',
+        'EVT_GRID_CMD_CELL_LEFT_DCLICK',
+        'EVT_GRID_CMD_CELL_RIGHT_DCLICK',
+        'EVT_GRID_CMD_LABEL_LEFT_CLICK',
+        'EVT_GRID_CMD_LABEL_RIGHT_CLICK',
+        'EVT_GRID_CMD_LABEL_LEFT_DCLICK',
+        'EVT_GRID_CMD_LABEL_RIGHT_DCLICK',
+        'EVT_GRID_CMD_CELL_CHANGE',
+        'EVT_GRID_CMD_SELECT_CELL',
+        'EVT_GRID_CMD_EDITOR_HIDDEN',
+        'EVT_GRID_CMD_EDITOR_SHOWN',
+        'EVT_GRID_CMD_COL_SIZE',
+        'EVT_GRID_CMD_ROW_SIZE',
+        'EVT_GRID_CMD_RANGE_SELECT',
+        'EVT_GRID_CMD_EDITOR_CREATED',
+        ]
+    
     def __init__(self, name, parent, id, sizer, pos, property_window,
                  show=True):
         """\
@@ -107,59 +127,69 @@ class EditGrid(ManagedBase):
         af = self.access_functions
         af['create_grid'] = (self.get_create_grid, self.set_create_grid)
         props['create_grid'] = CheckBoxProperty(self, 'create_grid', None,
-                                                write_always=True)
+                                                write_always=True,
+                                                label=_("create_grid"))
         af['row_label_size'] = (self.get_row_label_size,
                                 self.set_row_label_size)
         props['row_label_size'] = SpinProperty(self, 'row_label_size',
-                                               None, can_disable=True)
+                                               None, can_disable=True,
+                                               label=_("row_label_size"))
         af['col_label_size'] = (self.get_col_label_size,
                                 self.set_col_label_size)
         props['col_label_size'] = SpinProperty(self, 'col_label_size',
-                                               None, can_disable=True)
+                                               None, can_disable=True,
+                                               label=_("col_label_size"))
         af['enable_editing'] = (self.get_enable_editing,
                                 self.set_enable_editing)
         props['enable_editing'] = CheckBoxProperty(self, 'enable_editing',
-                                                   None, write_always=True)
+                                                   None, write_always=True,
+                                                   label=_("enable_editing"))
         af['enable_grid_lines'] = (self.get_enable_grid_lines,
                                    self.set_enable_grid_lines)
-        props['enable_grid_lines']= CheckBoxProperty(self, 'enable_grid_lines',
-                                                     None, write_always=True)
+        props['enable_grid_lines']= CheckBoxProperty(
+            self, 'enable_grid_lines', None, write_always=True,
+            label=_("enable_grid_lines"))
         af['rows_number'] = (self.get_rows_number, self.set_rows_number)
-        props['rows_number'] = SpinProperty(self, 'rows_number', None)
+        props['rows_number'] = SpinProperty(self, 'rows_number', None,
+                                            label=_("rows_number"))
         af['enable_col_resize'] = (self.get_enable_col_resize,
                                    self.set_enable_col_resize)
-        props['enable_col_resize']= CheckBoxProperty(self, 'enable_col_resize',
-                                                     None, write_always=True)
+        props['enable_col_resize']= CheckBoxProperty(
+            self, 'enable_col_resize', None, write_always=True,
+            label=_("enable_col_resize"))
         af['enable_row_resize'] = (self.get_enable_row_resize,
                                    self.set_enable_row_resize)
-        props['enable_row_resize'] = CheckBoxProperty(self,
-                                                      'enable_row_resize',
-                                                      None, write_always=True)
+        props['enable_row_resize'] = CheckBoxProperty(
+            self, 'enable_row_resize',
+            None, write_always=True, label=_("enable_row_resize"))
         af['enable_grid_resize'] = (self.get_enable_grid_resize,
                                     self.set_enable_grid_resize)
-        props['enable_grid_resize'] = CheckBoxProperty(self,
-                                                       'enable_grid_resize',
-                                                       None, write_always=True)
+        props['enable_grid_resize'] = CheckBoxProperty(
+            self, 'enable_grid_resize',
+            None, write_always=True, label=_("enable_grid_resize"))
         af['lines_color'] = (self.get_lines_color, self.set_lines_color)
-        props['lines_color']= ColorDialogProperty(self, 'lines_color', None)
+        props['lines_color']= ColorDialogProperty(
+            self, 'lines_color', None, label=_("lines_color"))
         af['label_bg_color'] = (self.get_label_bg_color,
                                 self.set_label_bg_color)
-        props['label_bg_color']= ColorDialogProperty(self, 'label_bg_color',
-                                                     None)
+        props['label_bg_color']= ColorDialogProperty(
+            self, 'label_bg_color', None, label=_("label_bg_color"))
         af['selection_mode'] = (self.get_selection_mode,
                                 self.set_selection_mode)
         props['selection_mode'] = RadioProperty(self, 'selection_mode', None, 
                                                 ['wxGrid.wxGridSelectCells',
                                                  'wxGrid.wxGridSelectRows',
-                                                 'wxGrid.wxGridSelectColumns'])
+                                                 'wxGrid.wxGridSelectColumns'],
+                                                label=_("selection_mode"))
         af['columns'] = (self.get_columns, self.set_columns)
         props['columns'] = GridColsProperty(self, 'columns', None, 
                                             [ ('Label', GridProperty.STRING),
-                                              ('Size', GridProperty.INT) ])
+                                              ('Size', GridProperty.INT) ],
+                                            label=_("columns"))
 
     def create_properties(self):
         ManagedBase.create_properties(self)
-        panel = wxScrolledWindow(self.notebook, -1, style=wxTAB_TRAVERSAL)
+        panel = wx.ScrolledWindow(self.notebook, -1, style=wx.TAB_TRAVERSAL)
         self.properties['create_grid'].display(panel)
         self.properties['columns'].display(panel)
         self.properties['rows_number'].display(panel)
@@ -173,37 +203,37 @@ class EditGrid(ManagedBase):
         self.properties['lines_color'].display(panel)
         self.properties['label_bg_color'].display(panel)
         self.properties['selection_mode'].display(panel)
-        szr = wxBoxSizer(wxVERTICAL)
-        szr.Add(self.properties['create_grid'].panel, 0, wxEXPAND)
-        szr.Add(wxStaticLine(panel, -1), 0, wxALL|wxEXPAND, 5)
-        szr.Add(wxStaticText(panel, -1, "The following properties are "
-                             "meaningful\nonly if 'Create grid' is selected"),
-                0, wxLEFT|wxRIGHT|wxEXPAND, 10)
-        szr.Add(wxStaticLine(panel, -1), 0, wxALL|wxEXPAND, 5)
-        szr.Add(self.properties['columns'].panel, 0, wxALL|wxEXPAND, 2)
+        szr = wx.BoxSizer(wx.VERTICAL)
+        szr.Add(self.properties['create_grid'].panel, 0, wx.EXPAND)
+        szr.Add(wx.StaticLine(panel, -1), 0, wx.ALL|wx.EXPAND, 5)
+        szr.Add(wx.StaticText(panel, -1, _("The following properties are "
+                             "meaningful\nonly if 'Create grid' is selected")),
+                0, wx.LEFT|wx.RIGHT|wx.EXPAND, 10)
+        szr.Add(wx.StaticLine(panel, -1), 0, wx.ALL|wx.EXPAND, 5)
+        szr.Add(self.properties['columns'].panel, 0, wx.ALL|wx.EXPAND, 2)
         szr.SetItemMinSize(self.properties['columns'].panel, 1, 150)
-        szr.Add(self.properties['rows_number'].panel, 0, wxEXPAND)
-        szr.Add(self.properties['row_label_size'].panel, 0, wxEXPAND)
-        szr.Add(self.properties['col_label_size'].panel, 0, wxEXPAND)
-        szr.Add(self.properties['lines_color'].panel, 0, wxEXPAND)
-        szr.Add(self.properties['label_bg_color'].panel, 0, wxEXPAND)
-        szr.Add(self.properties['enable_editing'].panel, 0, wxEXPAND)
-        szr.Add(self.properties['enable_grid_lines'].panel, 0, wxEXPAND)
-        szr.Add(self.properties['enable_col_resize'].panel, 0, wxEXPAND)
-        szr.Add(self.properties['enable_row_resize'].panel, 0, wxEXPAND)
-        szr.Add(self.properties['enable_grid_resize'].panel, 0, wxEXPAND)
-        szr.Add(self.properties['selection_mode'].panel, 0, wxALL|wxEXPAND, 5)
+        szr.Add(self.properties['rows_number'].panel, 0, wx.EXPAND)
+        szr.Add(self.properties['row_label_size'].panel, 0, wx.EXPAND)
+        szr.Add(self.properties['col_label_size'].panel, 0, wx.EXPAND)
+        szr.Add(self.properties['lines_color'].panel, 0, wx.EXPAND)
+        szr.Add(self.properties['label_bg_color'].panel, 0, wx.EXPAND)
+        szr.Add(self.properties['enable_editing'].panel, 0, wx.EXPAND)
+        szr.Add(self.properties['enable_grid_lines'].panel, 0, wx.EXPAND)
+        szr.Add(self.properties['enable_col_resize'].panel, 0, wx.EXPAND)
+        szr.Add(self.properties['enable_row_resize'].panel, 0, wx.EXPAND)
+        szr.Add(self.properties['enable_grid_resize'].panel, 0, wx.EXPAND)
+        szr.Add(self.properties['selection_mode'].panel, 0, wx.ALL|wx.EXPAND, 5)
         panel.SetAutoLayout(1)
         panel.SetSizer(szr)
         szr.Fit(panel)
         w, h = panel.GetClientSize()
-        self.notebook.AddPage(panel, 'Widget')
+        self.notebook.AddPage(panel, _('Widget'))
         import math
         panel.SetScrollbars(1, 5, 1, int(math.ceil(h/5.0)))
         self.properties['columns'].set_col_sizes([-1, 0])
 
     def create_widget(self):
-        self.widget = wxGrid(self.parent.widget, self.id,(200,200))
+        self.widget = Grid(self.parent.widget, self.id,(200,200))
         self.widget.CreateGrid(self.rows_number, len(self.columns))
         if not self.properties['label_bg_color'].is_active():
             self.label_bg_color = misc.color_to_string(
@@ -403,9 +433,9 @@ def builder(parent, sizer, pos, number=[1]):
     while common.app_tree.has_name(label):
         number[0] += 1
         label = 'grid_%d' % number[0]
-    grid = EditGrid(label, parent, wxNewId(), sizer, pos,
+    grid = EditGrid(label, parent, wx.NewId(), sizer, pos,
                     common.property_panel)
-    # A grid should be wxEXPANDed and 'option' should be 1,
+    # A grid should be wx.EXPANDed and 'option' should be 1,
     # or you can't see it.
     grid.set_option(1)  
     grid.set_flag("wxEXPAND")
@@ -421,10 +451,10 @@ def xml_builder(attrs, parent, sizer, sizeritem, pos=None):
     """
     from xml_parse import XmlParsingError
     try: label = attrs['name']
-    except KeyError: raise XmlParsingError, "'name' attribute missing"
+    except KeyError: raise XmlParsingError, _("'name' attribute missing")
     if sizer is None or sizeritem is None:
-        raise XmlParsingError, "sizer or sizeritem object cannot be None"
-    grid = EditGrid(label, parent, wxNewId(), sizer,
+        raise XmlParsingError, _("sizer or sizeritem object cannot be None")
+    grid = EditGrid(label, parent, wx.NewId(), sizer,
                     pos, common.property_panel, show=False)
     sizer.set_item(grid.pos, option=sizeritem.option, flag=sizeritem.flag,
                    border=sizeritem.border) #, size=(100,100))  #HELP#
@@ -437,7 +467,7 @@ def xml_builder(attrs, parent, sizer, sizeritem, pos=None):
 
 def initialize():
     """\
-    initialization function for the module: returns a wxBitmapButton to be
+    initialization function for the module: returns a wx.BitmapButton to be
     added to the main palette.
     """
     common.widgets['EditGrid'] = builder
