@@ -1,11 +1,11 @@
 # spacer.py: spacers to use in sizers
-# $Id: spacer.py,v 1.10 2005/05/06 21:48:18 agriggio Exp $
+# $Id: spacer.py,v 1.13 2007/08/07 12:18:34 agriggio Exp $
 #
-# Copyright (c) 2002-2005 Alberto Griggio <agriggio@users.sourceforge.net>
+# Copyright (c) 2002-2007 Alberto Griggio <agriggio@users.sourceforge.net>
 # License: MIT (see license.txt)
 # THIS PROGRAM COMES WITH NO WARRANTY
 
-from wxPython.wx import *
+import wx
 import common, misc
 from tree import Tree
 from widget_properties import *
@@ -24,12 +24,14 @@ class EditSpacer(ManagedBase):
         self.access_functions['width'] = (self.get_width, self.set_width)
         self.access_functions['height'] = (self.get_height, self.set_height)
 
-        self.properties['width'] = SpinProperty(self, 'width', None)
-        self.properties['height'] = SpinProperty(self, 'height', None)
+        self.properties['width'] = SpinProperty(self, 'width', None, label=_("width"))
+        self.properties['height'] = SpinProperty(self, 'height', None, label=_("height"))
 
     def create_widget(self):
-        self.widget = wxPanel(self.parent.widget, self.id, size=self.__size)
+        self.widget = wx.Window(self.parent.widget, self.id, size=self.__size,
+                                style=wx.SIMPLE_BORDER)
         self.widget.GetBestSize = self.widget.GetSize
+        wx.EVT_PAINT(self.widget, self.on_paint)
         
     def create_properties(self):
         ManagedBase.create_properties(self)
@@ -39,8 +41,8 @@ class EditSpacer(ManagedBase):
         wp.display(page)
         hp.display(page)
         szr = page.GetSizer()
-        szr.Insert(0, hp.panel, 0, wxEXPAND)
-        szr.Insert(0, wp.panel, 0, wxEXPAND)
+        szr.Insert(0, hp.panel, 0, wx.EXPAND)
+        szr.Insert(0, wp.panel, 0, wx.EXPAND)
         szr.Layout()
         szr.Fit(page)
         import math
@@ -73,9 +75,30 @@ class EditSpacer(ManagedBase):
 
     def set_flag(self, value):
         ManagedBase.set_flag(self, value)
-        if not (self.get_int_flag() & wxEXPAND):
+        if not (self.get_int_flag() & wx.EXPAND):
             self.sizer.set_item(self.pos, size=self.__size)
 
+    def on_paint(self, event):
+        dc = wx.PaintDC(self.widget)
+        dc.BeginDrawing()
+        brush = wx.TheBrushList.FindOrCreateBrush(
+            self.widget.GetBackgroundColour())
+        dc.SetBrush(brush)
+        dc.SetPen(wx.ThePenList.FindOrCreatePen(wx.BLACK, 1, wx.SOLID))
+        dc.SetBackground(brush)
+        dc.Clear()
+        w, h = self.widget.GetClientSize()
+        dc.DrawLine(0, 0, w, h)
+        dc.DrawLine(w, 0, 0, h)
+        text = _('Spacer')
+        tw, th = dc.GetTextExtent(text)
+        x = (w - tw)/2
+        y = (h - th)/2
+        dc.SetPen(wx.ThePenList.FindOrCreatePen(wx.BLACK, 0, wx.TRANSPARENT))
+        dc.DrawRectangle(x-1, y-1, tw+2, th+2)
+        dc.DrawText(text, x, y)
+        dc.EndDrawing()
+
 # end of class EditSpacer
         
 
@@ -83,26 +106,26 @@ def builder(parent, sizer, pos):
     """\
     factory function for EditSpacer objects.
     """
-    class Dialog(wxDialog):
+    class Dialog(wx.Dialog):
         def __init__(self):
-            wxDialog.__init__(self, misc.get_toplevel_parent(parent), -1,
-                              "Enter size")
+            wx.Dialog.__init__(self, misc.get_toplevel_parent(parent), -1,
+                              _("Enter size"))
             
-            self.width = SpinProperty(self, 'width', self)
-            self.height = SpinProperty(self, 'height', self)
+            self.width = SpinProperty(self, 'width', self, label=_("width"))
+            self.height = SpinProperty(self, 'height', self, label=_("height"))
             self.width.set_value(20)
             self.height.set_value(20)
             
-            szr = wxBoxSizer(wxVERTICAL)
-            szr.Add(self.width.panel, 0, wxEXPAND)
-            szr.Add(self.height.panel, 0, wxEXPAND)
-            sz = wxBoxSizer(wxHORIZONTAL)
-            sz.Add(wxButton(self, wxID_OK, 'OK'))
-            szr.Add(sz, 0, wxALL|wxALIGN_CENTER, 4)
+            szr = wx.BoxSizer(wx.VERTICAL)
+            szr.Add(self.width.panel, 0, wx.EXPAND)
+            szr.Add(self.height.panel, 0, wx.EXPAND)
+            sz = wx.BoxSizer(wx.HORIZONTAL)
+            sz.Add(wx.Button(self, wx.ID_OK, _('OK')))
+            szr.Add(sz, 0, wx.ALL|wx.ALIGN_CENTER, 4)
             self.SetAutoLayout(True)
             self.SetSizer(szr)
             szr.Fit(self)
-            self.Centre()
+            self.CenterOnScreen()
 
         def __getitem__(self, name):
             return (lambda : 0, lambda v: None)
@@ -112,7 +135,7 @@ def builder(parent, sizer, pos):
     dialog = Dialog()
     dialog.ShowModal()
     name = 'spacer'
-    spacer = EditSpacer(name, parent, wxNewId(), dialog.width.get_value(),
+    spacer = EditSpacer(name, parent, wx.NewId(), dialog.width.get_value(),
                         dialog.height.get_value(), sizer, pos,
                         common.property_panel)
     node = Tree.Node(spacer)
@@ -127,8 +150,8 @@ def xml_builder(attrs, parent, sizer, sizeritem, pos=None):
     """
     from xml_parse import XmlParsingError
     if not sizer or not sizeritem:
-        raise XmlParsingError, "sizer or sizeritem object cannot be None"
-    spacer = EditSpacer('spacer', parent, wxNewId(), 1, 1, sizer, pos,
+        raise XmlParsingError, _("sizer or sizeritem object cannot be None")
+    spacer = EditSpacer('spacer', parent, wx.NewId(), 1, 1, sizer, pos,
                         common.property_panel, True)
     sizer.set_item(spacer.pos, option=sizeritem.option, flag=sizeritem.flag,
                    border=sizeritem.border)
@@ -141,7 +164,7 @@ def xml_builder(attrs, parent, sizer, sizeritem, pos=None):
 
 def initialize():
     """\
-    initialization function for the module: returns a wxBitmapButton to be
+    initialization function for the module: returns a wx.BitmapButton to be
     added to the main palette.
     """
     common.widgets['EditSpacer'] = builder
