@@ -1,12 +1,13 @@
 # toolbar.py: wxToolBar objects
-# $Id: toolbar.py,v 1.21 2005/05/06 21:48:01 agriggio Exp $
+# $Id: toolbar.py,v 1.26 2007/08/07 12:18:33 agriggio Exp $
 #
-# Copyright (c) 2002-2005 Alberto Griggio <agriggio@users.sourceforge.net>
+# Copyright (c) 2002-2007 Alberto Griggio <agriggio@users.sourceforge.net>
 # License: MIT (see license.txt)
 # THIS PROGRAM COMES WITH NO WARRANTY
 
-from wxPython.wx import *
-from wxPython.lib.filebrowsebutton import FileBrowseButton
+import wx
+#from wxPython.lib.filebrowsebutton import FileBrowseButton
+from wx.lib.filebrowsebutton import FileBrowseButton
 
 import common, math, misc, os
 from tree import Tree
@@ -18,13 +19,13 @@ from edit_windows import EditBase, TopLevelBase, PreviewMixin
 class _MyBrowseButton(FileBrowseButton):
     def createBrowseButton( self):
         """Create the browse-button control"""
-        ID = wxNewId()
-        button =wxButton(self, ID, misc.wxstr(self.buttonText))
+        ID = wx.NewId()
+        button =wx.Button(self, ID, misc.wxstr(self.buttonText))
         button.SetToolTipString(misc.wxstr(self.toolTip))
         w = button.GetTextExtent(self.buttonText)[0] + 10
         if not misc.check_wx_version(2, 5, 2): button.SetSize((w, -1))
         else: button.SetMinSize((w, -1))
-        EVT_BUTTON(button, ID, self.OnBrowse)
+        wx.EVT_BUTTON(button, ID, self.OnBrowse)
         return button
 
     def OnBrowse (self, event=None):
@@ -47,31 +48,33 @@ class _MyBrowseButton(FileBrowseButton):
 # end of class _MyBrowseButton
 
 
-class ToolsDialog(wxDialog):
-    def __init__(self, parent, items=None):
-        wxDialog.__init__(self, parent, -1, "Toolbar editor",
-                          style=wxDEFAULT_DIALOG_STYLE|wxRESIZE_BORDER)
+class ToolsDialog(wx.Dialog):
+    def __init__(self, parent, owner, items=None):
+        wx.Dialog.__init__(self, parent, -1, _("Toolbar editor"),
+                          style=wx.DEFAULT_DIALOG_STYLE|wx.RESIZE_BORDER)
         ADD_ID, REMOVE_ID, NAME_ID, LABEL_ID, ID_ID, CHECK_RADIO_ID, LIST_ID, \
                 ADD_SEP_ID, MOVE_UP_ID, MOVE_DOWN_ID, HELP_STR_ID, \
                 LONG_HELP_STR_ID, BITMAP1_ID, BITMAP2_ID \
-                = [wxNewId() for i in range(14)]
+                = [wx.NewId() for i in range(14)]
 
-        self._staticbox = wxStaticBox(self, -1, "Tool:")
+        self._staticbox = wx.StaticBox(self, -1, _("Tool:"))
+
+        self.owner = owner
         
-        self.tool_items = wxListCtrl(self, LIST_ID, style=wxLC_REPORT | \
-                                     wxLC_SINGLE_SEL|wxSUNKEN_BORDER,
+        self.tool_items = wx.ListCtrl(self, LIST_ID, style=wx.LC_REPORT | \
+                                     wx.LC_SINGLE_SEL|wx.SUNKEN_BORDER,
                                      size=(300, -1))
         self.selected_index = -1 # index of the selected element in the 
                                  # wxListCtrl 
-        self.tool_items.InsertColumn(0, "Label")
-        self.tool_items.InsertColumn(1, "Id")
-        self.tool_items.InsertColumn(2, "Normal Bitmap")
-        self.tool_items.InsertColumn(3, "Second Bitmap")
-        self.tool_items.InsertColumn(4, "Short Help")
-        self.tool_items.InsertColumn(5, "Long Help")
-        self.tool_items.InsertColumn(6, "Type")
+        self.tool_items.InsertColumn(0, _("Label"))
+        self.tool_items.InsertColumn(1, _("Id"))
+        self.tool_items.InsertColumn(2, _("Normal Bitmap"))
+        self.tool_items.InsertColumn(3, _("Second Bitmap"))
+        self.tool_items.InsertColumn(4, _("Short Help"))
+        self.tool_items.InsertColumn(5, _("Long Help"))
+        self.tool_items.InsertColumn(6, _("Type"))
         # ALB 2004-12-05
-        self.tool_items.InsertColumn(7, "Event Handler")
+        self.tool_items.InsertColumn(7, _("Event Handler"))
 
         self.tool_items.SetColumnWidth(0, 100)
         self.tool_items.SetColumnWidth(2, 100)
@@ -82,50 +85,52 @@ class ToolsDialog(wxDialog):
         self.tool_items.SetColumnWidth(7, 150)
         
         # tool fields
-        self.id = wxTextCtrl(self, ID_ID)
-        self.label = wxTextCtrl(self, LABEL_ID)
-        self.help_str = wxTextCtrl(self, HELP_STR_ID)
-        self.long_help_str = wxTextCtrl(self, LONG_HELP_STR_ID)
+        self.id = wx.TextCtrl(self, ID_ID)
+        self.label = wx.TextCtrl(self, LABEL_ID)
+        self.help_str = wx.TextCtrl(self, HELP_STR_ID)
+        self.long_help_str = wx.TextCtrl(self, LONG_HELP_STR_ID)
         # ALB 2004-12-05
-        self.event_handler = wxTextCtrl(self, -1)
+        self.event_handler = wx.TextCtrl(self, -1)
         import re
         self.handler_re = re.compile(r'^\s*\w*\s*$')
 
         self.bitmap1 = _MyBrowseButton(
-            self, BITMAP1_ID, labelText='Normal Bitmap', buttonText='...',
+            self, BITMAP1_ID, labelText=_('Normal Bitmap'), buttonText='...',
             changeCallback=self.update_tool)
         self.bitmap2 = _MyBrowseButton(
-            self, BITMAP2_ID, labelText='Second Bitmap', buttonText='...',
+            self, BITMAP2_ID, labelText=_('Second Bitmap'), buttonText='...',
             changeCallback=self.update_tool)
-        self.check_radio = wxRadioBox(
-            self, CHECK_RADIO_ID, "Type",
+        self.check_radio = wx.RadioBox(
+            self, CHECK_RADIO_ID, _("Type"),
             choices=['Normal', 'Checkable', 'Radio'], majorDimension=3)
 
-        self.add = wxButton(self, ADD_ID, "Add")
-        self.remove = wxButton(self, REMOVE_ID, "Remove")
-        self.add_sep = wxButton(self, ADD_SEP_ID, "Add separator")
+        self.add = wx.Button(self, ADD_ID, _("Add"))
+        self.remove = wx.Button(self, REMOVE_ID, _("Remove"))
+        self.add_sep = wx.Button(self, ADD_SEP_ID, _("Add separator"))
 
         # tools navigation
-        self.move_up = wxButton(self, MOVE_UP_ID, "Up")
-        self.move_down = wxButton(self, MOVE_DOWN_ID, "Down")
+        self.move_up = wx.Button(self, MOVE_UP_ID, _("Up"))
+        self.move_down = wx.Button(self, MOVE_DOWN_ID, _("Down"))
 
-        self.ok = wxButton(self, wxID_OK, "OK")
-        self.cancel = wxButton(self, wxID_CANCEL, "Cancel")
+        self.ok = wx.Button(self, wx.ID_OK, _("OK"))
+        self.apply = wx.Button(self, wx.ID_APPLY, _("Apply"))
+        self.cancel = wx.Button(self, wx.ID_CANCEL, _("Cancel"))
 
         self.do_layout()
         # event handlers
-        EVT_BUTTON(self, ADD_ID, self.add_tool)
-        EVT_BUTTON(self, REMOVE_ID, self.remove_tool)
-        EVT_BUTTON(self, ADD_SEP_ID, self.add_separator)
-        EVT_BUTTON(self, MOVE_UP_ID, self.move_item_up)
-        EVT_BUTTON(self, MOVE_DOWN_ID, self.move_item_down)
-        EVT_KILL_FOCUS(self.label, self.update_tool)
-        EVT_KILL_FOCUS(self.id, self.update_tool)
-        EVT_KILL_FOCUS(self.help_str, self.update_tool)
-        EVT_KILL_FOCUS(self.long_help_str, self.update_tool)
-        EVT_KILL_FOCUS(self.event_handler, self.update_tool)
-        EVT_RADIOBOX(self, CHECK_RADIO_ID, self.update_tool)
-        EVT_LIST_ITEM_SELECTED(self, LIST_ID, self.show_tool)
+        wx.EVT_BUTTON(self, ADD_ID, self.add_tool)
+        wx.EVT_BUTTON(self, REMOVE_ID, self.remove_tool)
+        wx.EVT_BUTTON(self, ADD_SEP_ID, self.add_separator)
+        wx.EVT_BUTTON(self, MOVE_UP_ID, self.move_item_up)
+        wx.EVT_BUTTON(self, MOVE_DOWN_ID, self.move_item_down)
+        wx.EVT_BUTTON(self, wx.ID_APPLY, self.on_apply)
+        wx.EVT_KILL_FOCUS(self.label, self.update_tool)
+        wx.EVT_KILL_FOCUS(self.id, self.update_tool)
+        wx.EVT_KILL_FOCUS(self.help_str, self.update_tool)
+        wx.EVT_KILL_FOCUS(self.long_help_str, self.update_tool)
+        wx.EVT_KILL_FOCUS(self.event_handler, self.update_tool)
+        wx.EVT_RADIOBOX(self, CHECK_RADIO_ID, self.update_tool)
+        wx.EVT_LIST_ITEM_SELECTED(self, LIST_ID, self.show_tool)
         if items:
             self.add_tools(items)
 
@@ -139,59 +144,60 @@ class ToolsDialog(wxDialog):
         self.bitmap2.Enable(False)
         self.check_radio.Enable(False)
         
-        sizer = wxBoxSizer(wxVERTICAL)
-        sizer2 = wxStaticBoxSizer(self._staticbox, wxVERTICAL)
+        sizer = wx.BoxSizer(wx.VERTICAL)
+        sizer2 = wx.StaticBoxSizer(self._staticbox, wx.VERTICAL)
         self.label.SetSize((150, -1))
         self.id.SetSize((150, -1))
         self.help_str.SetSize((150, -1))
         self.long_help_str.SetSize((150, -1))
         self.event_handler.SetSize((150, -1))
-        szr = wxFlexGridSizer(0, 2)
+        szr = wx.FlexGridSizer(0, 2)
         if misc.check_wx_version(2, 5, 2):
-            flag = wxFIXED_MINSIZE
+            flag = wx.FIXED_MINSIZE
         else:
             flag = 0
-        label_flag = wxALIGN_CENTER_VERTICAL
-        szr.Add(wxStaticText(self, -1, "Id   "), flag=label_flag)
+        label_flag = wx.ALIGN_CENTER_VERTICAL
+        szr.Add(wx.StaticText(self, -1, _("Id   ")), flag=label_flag)
         szr.Add(self.id, flag=flag)
-        szr.Add(wxStaticText(self, -1, "Label  "), flag=label_flag)
+        szr.Add(wx.StaticText(self, -1, _("Label  ")), flag=label_flag)
         szr.Add(self.label, flag=flag)
-        szr.Add(wxStaticText(self, -1, "Short Help  "), flag=label_flag)
+        szr.Add(wx.StaticText(self, -1, _("Short Help  ")), flag=label_flag)
         szr.Add(self.help_str, flag=flag)
-        szr.Add(wxStaticText(self, -1, "Long Help  "), flag=label_flag)
+        szr.Add(wx.StaticText(self, -1, _("Long Help  ")), flag=label_flag)
         szr.Add(self.long_help_str, flag=flag)
-        szr.Add(wxStaticText(self, -1, "Event Handler  "), flag=label_flag)
+        szr.Add(wx.StaticText(self, -1, _("Event Handler  ")), flag=label_flag)
         szr.Add(self.event_handler, flag=flag)
-        sizer2.Add(szr, 1, wxALL|wxEXPAND, 5)
+        sizer2.Add(szr, 1, wx.ALL|wx.EXPAND, 5)
         label_w = self.bitmap1.browseButton.GetTextExtent('...')[0]
-        sizer2.Add(self.bitmap1, 0, wxEXPAND)
-        sizer2.Add(self.bitmap2, 0, wxEXPAND)
-        sizer2.Add(self.check_radio, 0, wxLEFT|wxRIGHT|wxBOTTOM, 4)
-        szr = wxGridSizer(0, 2, 3, 3)
-        szr.Add(self.add, 0, wxEXPAND); szr.Add(self.remove, 0, wxEXPAND)
-        sizer2.Add(szr, 0, wxEXPAND)
-        sizer2.Add(self.add_sep, 0, wxTOP|wxEXPAND, 3)
+        sizer2.Add(self.bitmap1, 0, wx.EXPAND)
+        sizer2.Add(self.bitmap2, 0, wx.EXPAND)
+        sizer2.Add(self.check_radio, 0, wx.LEFT|wx.RIGHT|wx.BOTTOM, 4)
+        szr = wx.GridSizer(0, 2, 3, 3)
+        szr.Add(self.add, 0, wx.EXPAND); szr.Add(self.remove, 0, wx.EXPAND)
+        sizer2.Add(szr, 0, wx.EXPAND)
+        sizer2.Add(self.add_sep, 0, wx.TOP|wx.EXPAND, 3)
 
-        sizer3 = wxBoxSizer(wxVERTICAL)
-        sizer3.Add(self.tool_items, 1, wxALL|wxEXPAND, 5)
-        sizer4 = wxBoxSizer(wxHORIZONTAL)
+        sizer3 = wx.BoxSizer(wx.VERTICAL)
+        sizer3.Add(self.tool_items, 1, wx.ALL|wx.EXPAND, 5)
+        sizer4 = wx.BoxSizer(wx.HORIZONTAL)
 
-        sizer4.Add(self.move_up, 0, wxLEFT|wxRIGHT, 3)
-        sizer4.Add(self.move_down, 0, wxLEFT|wxRIGHT, 5)
-        sizer3.Add(sizer4, 0, wxALIGN_CENTER|wxALL, 5)
-        szr = wxBoxSizer(wxHORIZONTAL)
-        szr.Add(sizer3, 1, wxALL|wxEXPAND, 5) 
-        szr.Add(sizer2, 0, wxTOP|wxBOTTOM|wxRIGHT, 5)
-        sizer.Add(szr, 1, wxEXPAND)
-        sizer2 = wxBoxSizer(wxHORIZONTAL)
-        sizer2.Add(self.ok, 0, wxALL, 5)
-        sizer2.Add(self.cancel, 0, wxALL, 5)
-        sizer.Add(sizer2, 0, wxALL|wxALIGN_CENTER, 3)
+        sizer4.Add(self.move_up, 0, wx.LEFT|wx.RIGHT, 3)
+        sizer4.Add(self.move_down, 0, wx.LEFT|wx.RIGHT, 5)
+        sizer3.Add(sizer4, 0, wx.ALIGN_CENTER|wx.ALL, 5)
+        szr = wx.BoxSizer(wx.HORIZONTAL)
+        szr.Add(sizer3, 1, wx.ALL|wx.EXPAND, 5) 
+        szr.Add(sizer2, 0, wx.TOP|wx.BOTTOM|wx.RIGHT, 5)
+        sizer.Add(szr, 1, wx.EXPAND)
+        sizer2 = wx.BoxSizer(wx.HORIZONTAL)
+        sizer2.Add(self.ok, 0, wx.ALL, 5)
+        sizer2.Add(self.apply, 0, wx.ALL, 5)
+        sizer2.Add(self.cancel, 0, wx.ALL, 5)
+        sizer.Add(sizer2, 0, wx.ALL|wx.ALIGN_CENTER, 3)
         self.SetAutoLayout(1)
         self.SetSizer(sizer)
         sizer.Fit(self)
         #self.SetSize((-1, 350))
-        self.CenterOnParent()
+        self.CenterOnScreen()
 
     def add_tool(self, event):
         """\
@@ -213,8 +219,8 @@ class ToolsDialog(wxDialog):
         self.tool_items.SetStringItem(index, 4, help_str)
         self.tool_items.SetStringItem(index, 5, long_help_str)
         self.tool_items.SetStringItem(index, 6, check_radio)
-        self.tool_items.SetItemState(index, wxLIST_STATE_SELECTED,
-                                     wxLIST_STATE_SELECTED)
+        self.tool_items.SetItemState(index, wx.LIST_STATE_SELECTED,
+                                     wx.LIST_STATE_SELECTED)
         self.label.SetValue(label)
         self.id.SetValue(id)
         self.check_radio.SetSelection(int(check_radio))
@@ -238,8 +244,8 @@ class ToolsDialog(wxDialog):
         self.tool_items.InsertStringItem(index, '---')#label)
         for i in range(1, 5):
             self.tool_items.SetStringItem(index, i, '---')
-        self.tool_items.SetItemState(index, wxLIST_STATE_SELECTED,
-                                     wxLIST_STATE_SELECTED)
+        self.tool_items.SetItemState(index, wx.LIST_STATE_SELECTED,
+                                     wx.LIST_STATE_SELECTED)
 
     def show_tool(self, event):
         """\
@@ -386,7 +392,7 @@ class ToolsDialog(wxDialog):
             for i in range(8):
                 self.tool_items.SetStringItem(index, i, vals1[i])
                 self.tool_items.SetStringItem(self.selected_index, i, vals2[i])
-            state = wxLIST_STATE_SELECTED | wxLIST_STATE_FOCUSED
+            state = wx.LIST_STATE_SELECTED | wx.LIST_STATE_FOCUSED
             self.tool_items.SetItemState(index, state, state)
             self.selected_index = index
 
@@ -405,11 +411,15 @@ class ToolsDialog(wxDialog):
             for i in range(8):
                 self.tool_items.SetStringItem(index, i, vals1[i])
                 self.tool_items.SetStringItem(self.selected_index, i, vals2[i])
-            state = wxLIST_STATE_SELECTED | wxLIST_STATE_FOCUSED
+            state = wx.LIST_STATE_SELECTED | wx.LIST_STATE_FOCUSED
             self.tool_items.SetItemState(index, state, state)
             self.selected_index = index
-                                                  
-#end of class ToolsDialog
+
+    def on_apply(self, event):
+        self.owner.set_tools(self.get_tools())
+        common.app_tree.app.saved = False
+
+# end of class ToolsDialog
 
 
 class ToolsProperty(Property):
@@ -423,21 +433,23 @@ class ToolsProperty(Property):
         if parent is not None: self.display(parent)
 
     def display(self, parent):
-        self.panel = wxPanel(parent, -1)
-        edit_btn_id = wxNewId()
-        self.edit_btn = wxButton(self.panel, edit_btn_id, "Edit tools...")
-        sizer = wxBoxSizer(wxHORIZONTAL)
-        sizer.Add(self.edit_btn, 1, wxEXPAND|wxALIGN_CENTER|wxTOP|wxBOTTOM, 4)
+        self.panel = wx.Panel(parent, -1)
+        edit_btn_id = wx.NewId()
+        self.edit_btn = wx.Button(self.panel, edit_btn_id, _("Edit tools..."))
+        sizer = wx.BoxSizer(wx.HORIZONTAL)
+        sizer.Add(self.edit_btn, 1, wx.EXPAND|wx.ALIGN_CENTER|wx.TOP|wx.BOTTOM,
+                  4)
         self.panel.SetAutoLayout(1)
         self.panel.SetSizer(sizer)
         self.panel.SetSize(sizer.GetMinSize())
-        EVT_BUTTON(self.panel, edit_btn_id, self.edit_tools)
+        wx.EVT_BUTTON(self.panel, edit_btn_id, self.edit_tools)
 
     def bind_event(*args): pass
 
     def edit_tools(self, event):
-        dialog = ToolsDialog(self.panel, items=self.owner.get_tools())
-        if dialog.ShowModal() == wxID_OK:
+        dialog = ToolsDialog(self.panel, self.owner,
+                             items=self.owner.get_tools())
+        if dialog.ShowModal() == wx.ID_OK:
             self.owner.set_tools(dialog.get_tools())
             common.app_tree.app.saved = False # update the status of the app
 
@@ -448,30 +460,30 @@ class ToolsProperty(Property):
             tool.write(outfile, tabs+1)
         fwrite('    ' * tabs + '</tools>\n')
 
-# end of class MenuProperty
+# end of class ToolsProperty
 
 
 class EditToolBar(EditBase, PreviewMixin):
     def __init__(self, name, klass, parent, property_window):
         custom_class = parent is None
         EditBase.__init__(self, name, klass,
-                          parent, wxNewId(), property_window,
+                          parent, wx.NewId(), property_window,
                           custom_class=custom_class, show=False)
-        self.base = 'wxToolBar'
+        self.base = 'wx.ToolBar'
         
         def nil(*args): return ()
         self.tools = [] # list of Tool objects
         self._tb = None # the real toolbar
         self.style = 0
         self.access_functions['style'] = (self.get_style, self.set_style)
-        self.style_pos  = [wxTB_FLAT, wxTB_DOCKABLE, wxTB_3DBUTTONS]
+        self.style_pos  = [wx.TB_FLAT, wx.TB_DOCKABLE, wx.TB_3DBUTTONS]
         if misc.check_wx_version(2, 3, 3):
-            self.style_pos += [wxTB_TEXT, wxTB_NOICONS, wxTB_NODIVIDER,
-                               wxTB_NOALIGN]
+            self.style_pos += [wx.TB_TEXT, wx.TB_NOICONS, wx.TB_NODIVIDER,
+                               wx.TB_NOALIGN]
         if misc.check_wx_version(2, 5, 0):
-            self.style_pos += [wxTB_HORZ_LAYOUT, wxTB_HORZ_TEXT]
+            self.style_pos += [wx.TB_HORZ_LAYOUT, wx.TB_HORZ_TEXT]
  
-        style_labels = ['#section#Style', 'wxTB_FLAT', 'wxTB_DOCKABLE',
+        style_labels = ['#section#' + _('Style'), 'wxTB_FLAT', 'wxTB_DOCKABLE',
                         'wxTB_3DBUTTONS']
         if misc.check_wx_version(2, 3, 3):
             style_labels += ['wxTB_TEXT', 'wxTB_NOICONS',
@@ -484,46 +496,51 @@ class EditToolBar(EditBase, PreviewMixin):
         self.access_functions['bitmapsize'] = (self.get_bitmapsize,
                                                self.set_bitmapsize)
         self.properties['bitmapsize'] = TextProperty(self, 'bitmapsize', None,
-                                                     can_disable=True)
+                                                     can_disable=True, label=_("bitmapsize"))
         self.margins = '0, 0'
         self.access_functions['margins'] = (self.get_margins, self.set_margins)
         self.properties['margins'] = TextProperty(self, 'margins', None,
-                                                  can_disable=True)
+                                                  can_disable=True, label=_("margins"))
         self.access_functions['tools'] = (self.get_tools, self.set_tools)
         prop = self.properties['tools'] = ToolsProperty(self, 'tools', None)
         self.packing = 1
         self.access_functions['packing'] = (self.get_packing, self.set_packing)
         self.properties['packing'] = SpinProperty(self, 'packing', None,
-                                                  r=(0, 100), can_disable=True)
+                                                  r=(0, 100), can_disable=True, label=_("packing"))
         self.separation = 5
         self.access_functions['separation'] = (self.get_separation,
                                                self.set_separation)
         self.properties['separation'] = SpinProperty(
-            self, 'separation', None, r=(0, 100), can_disable=True)
+            self, 'separation', None, r=(0, 100), can_disable=True, label=_("separation"))
         # 2003-05-07 preview support
         PreviewMixin.__init__(self)
 
     def create_widget(self):
-        tb_style = wxTB_HORIZONTAL|self.style
-        if wxPlatform == '__WXGTK__': tb_style |= wxTB_DOCKABLE|wxTB_FLAT
+        tb_style = wx.TB_HORIZONTAL|self.style
+        if wx.Platform == '__WXGTK__': tb_style |= wx.TB_DOCKABLE|wx.TB_FLAT
         if self.parent:
-            self.widget = self._tb = wxToolBar(
+            self.widget = self._tb = wx.ToolBar(
                 self.parent.widget, -1, style=tb_style)
             self.parent.widget.SetToolBar(self.widget)
         else:
             # "top-level" toolbar
-            self.widget = wxFrame(None, -1, misc.design_title(self.name))
+            self.widget = wx.Frame(None, -1, misc.design_title(self.name))
             self.widget.SetClientSize((400, 30))
-            self._tb = wxToolBar(self.widget, -1, style=tb_style)
+            self._tb = wx.ToolBar(self.widget, -1, style=tb_style)
             self.widget.SetToolBar(self._tb)
             self.widget.SetBackgroundColour(self._tb.GetBackgroundColour())
-            EVT_CLOSE(self.widget, lambda e: self.hide_widget())
-            EVT_LEFT_DOWN(self._tb, self.on_set_focus)
-            if wxPlatform == '__WXMSW__':
+            import os
+            icon = wx.EmptyIcon()
+            xpm = os.path.join(common.wxglade_path, 'icons', 'toolbar.xpm')
+            icon.CopyFromBitmap(misc.get_xpm_bitmap(xpm))
+            self.widget.SetIcon(icon)
+            wx.EVT_CLOSE(self.widget, lambda e: self.hide_widget())
+            wx.EVT_LEFT_DOWN(self._tb, self.on_set_focus)
+            if wx.Platform == '__WXMSW__':
                 # MSW isn't smart enough to avoid overlapping windows, so
                 # at least move it away from the 3 wxGlade frames
                 self.widget.CenterOnScreen()
-        EVT_LEFT_DOWN(self.widget, self.on_set_focus)
+        wx.EVT_LEFT_DOWN(self.widget, self.on_set_focus)
         # set the various property values
         prop = self.properties
         if prop['bitmapsize'].is_active():
@@ -547,21 +564,21 @@ class EditToolBar(EditBase, PreviewMixin):
         self.properties['style'].display(page)
         self.properties['tools'].display(page)
         if not sizer:
-            sizer = wxBoxSizer(wxVERTICAL)
-            sizer.Add(self.name_prop.panel, 0, wxEXPAND)
-            sizer.Add(self.klass_prop.panel, 0, wxEXPAND)
+            sizer = wx.BoxSizer(wx.VERTICAL)
+            sizer.Add(self.name_prop.panel, 0, wx.EXPAND)
+            sizer.Add(self.klass_prop.panel, 0, wx.EXPAND)
             page.SetAutoLayout(1)
             page.SetSizer(sizer)
-        sizer.Add(self.properties['bitmapsize'].panel, 0, wxEXPAND)
-        sizer.Add(self.properties['margins'].panel, 0, wxEXPAND)
-        sizer.Add(self.properties['packing'].panel, 0, wxEXPAND)
-        sizer.Add(self.properties['separation'].panel, 0, wxEXPAND)
-        sizer.Add(self.properties['style'].panel, 0, wxEXPAND)
-        sizer.Add(self.properties['tools'].panel, 0, wxALL|wxEXPAND, 3)
+        sizer.Add(self.properties['bitmapsize'].panel, 0, wx.EXPAND)
+        sizer.Add(self.properties['margins'].panel, 0, wx.EXPAND)
+        sizer.Add(self.properties['packing'].panel, 0, wx.EXPAND)
+        sizer.Add(self.properties['separation'].panel, 0, wx.EXPAND)
+        sizer.Add(self.properties['style'].panel, 0, wx.EXPAND)
+        sizer.Add(self.properties['tools'].panel, 0, wx.ALL|wx.EXPAND, 3)
         sizer.Layout()
         sizer.Fit(page)
         w, h = page.GetClientSize()
-        self.notebook.AddPage(page, "Common")
+        self.notebook.AddPage(page, _("Common"))
         if self.parent is not None:
             self.property_window.Layout()
             page.SetScrollbars(1, 5, 1, int(math.ceil(h/5.0)))
@@ -662,24 +679,24 @@ class EditToolBar(EditBase, PreviewMixin):
             else:
                 if tool.bitmap1:
                     bmp1 = None
-                    if not ( tool.bitmap1.startswith('var:') or
-                              tool.bitmap1.startswith('code:')
-                            ):
-                        bmp1 = wxBitmap(misc.wxstr(tool.bitmap1),
-                                    wxBITMAP_TYPE_ANY)
-                    if not bmp1 or not bmp1.Ok(): bmp1 = wxEmptyBitmap(1, 1)
+                    if not (tool.bitmap1.startswith('var:') or
+                            tool.bitmap1.startswith('code:')):
+                        bmp1 = wx.Bitmap(
+                            misc.get_relative_path(misc.wxstr(tool.bitmap1)),
+                            wx.BITMAP_TYPE_ANY)
+                    if not bmp1 or not bmp1.Ok(): bmp1 = wx.EmptyBitmap(1, 1)
                 else:
-                    bmp1 = wxNullBitmap
+                    bmp1 = wx.NullBitmap
                 if tool.bitmap2:
                     bmp2 = None
-                    if not ( tool.bitmap2.startswith('var:') or
-                              tool.bitmap2.startswith('code:')
-                            ):
-                        bmp2 = wxBitmap(misc.wxstr(tool.bitmap2),
-                                    wxBITMAP_TYPE_ANY)
-                    if not bmp2 or not bmp2.Ok(): bmp2 = wxEmptyBitmap(1, 1)
+                    if not (tool.bitmap2.startswith('var:') or
+                            tool.bitmap2.startswith('code:')):
+                        bmp2 = wx.Bitmap(
+                            misc.get_relative_path(misc.wxstr(tool.bitmap2)),
+                            wx.BITMAP_TYPE_ANY)
+                    if not bmp2 or not bmp2.Ok(): bmp2 = wx.EmptyBitmap(1, 1)
                 else:
-                    bmp2 = wxNullBitmap
+                    bmp2 = wx.NullBitmap
                 # signature of AddTool for 2.3.2.1:
                 # wxToolBarToolBase *AddTool(
                 #    int id, const wxBitmap& bitmap,
@@ -689,17 +706,17 @@ class EditToolBar(EditBase, PreviewMixin):
                 #    const wxString& longHelpString = wxEmptyString)
                 if not misc.check_wx_version(2, 3, 3):
                     # use the old signature, some of the entries are ignored
-                    self._tb.AddTool(wxNewId(), bmp1, bmp2, tool.type == 1,
+                    self._tb.AddTool(wx.NewId(), bmp1, bmp2, tool.type == 1,
                                      shortHelpString=\
                                      misc.wxstr(tool.short_help),
                                      longHelpString=misc.wxstr(tool.long_help))
                 else:
-                    kinds = [wxITEM_NORMAL, wxITEM_CHECK, wxITEM_RADIO]
+                    kinds = [wx.ITEM_NORMAL, wx.ITEM_CHECK, wx.ITEM_RADIO]
                     try:
                         kind = kinds[int(tool.type)]
                     except (ValueError, IndexError):
-                        kind = wxITEM_NORMAL
-                    self._tb.AddLabelTool(wxNewId(), misc.wxstr(tool.label),
+                        kind = wx.ITEM_NORMAL
+                    self._tb.AddLabelTool(wx.NewId(), misc.wxstr(tool.label),
                                           bmp1, bmp2, kind,
                                           misc.wxstr(tool.short_help),
                                           misc.wxstr(tool.long_help))
@@ -740,15 +757,15 @@ class EditToolBar(EditBase, PreviewMixin):
             return # do nothing in this case
         if self.widget:
             if not self._rmenu:
-                REMOVE_ID, HIDE_ID = [wxNewId() for i in range(2)]
+                REMOVE_ID, HIDE_ID = [wx.NewId() for i in range(2)]
                 self._rmenu = misc.wxGladePopupMenu(self.name)
-                misc.append_item(self._rmenu, REMOVE_ID, 'Remove\tDel',
-                                 'remove.xpm')
-                misc.append_item(self._rmenu, HIDE_ID, 'Hide') 
+                misc.append_item(self._rmenu, REMOVE_ID, _('Remove\tDel'),
+                                 wx.ART_DELETE)
+                misc.append_item(self._rmenu, HIDE_ID, _('Hide')) 
                 def bind(method):
                     return lambda e: misc.wxCallAfter(method)
-                EVT_MENU(self.widget, REMOVE_ID, bind(self.remove))
-                EVT_MENU(self.widget, HIDE_ID, bind(self.hide_widget))
+                wx.EVT_MENU(self.widget, REMOVE_ID, bind(self.remove))
+                wx.EVT_MENU(self.widget, HIDE_ID, bind(self.hide_widget))
                 
             self.widget.PopupMenu(self._rmenu, event.GetPosition())
 
@@ -784,7 +801,7 @@ class EditToolBar(EditBase, PreviewMixin):
                         self.curr_index = -1
                         pass # just ignore the attributes we don't know
 ##                         from xml_parse import XmlParsingError
-##                         raise XmlParsingError, "invalid tool attribute"
+##                         raise XmlParsingError, _("invalid tool attribute")
             def end_elem(self, name):
                 if name == 'tool':
                     self.tools.append(self.curr_tool)
@@ -807,9 +824,9 @@ def builder(parent, sizer, pos, number=[0]):
     """\
     factory function for EditToolBar objects.
     """
-    class Dialog(wxDialog):
+    class Dialog(wx.Dialog):
         def __init__(self):
-            wxDialog.__init__(self, None, -1, 'Select toolbar class')
+            wx.Dialog.__init__(self, None, -1, _('Select toolbar class'))
             if common.app_tree.app.get_language().lower() == 'xrc':
                 self.klass = 'wxToolBar'
             else:
@@ -817,12 +834,12 @@ def builder(parent, sizer, pos, number=[0]):
                 else: self.klass = 'MyToolBar%s' % number[0]
                 number[0] += 1
             klass_prop = TextProperty(self, 'class', self)
-            szr = wxBoxSizer(wxVERTICAL)
-            szr.Add(klass_prop.panel, 0, wxEXPAND)
-            sz2 = wxBoxSizer(wxHORIZONTAL)
-            sz2.Add(wxButton(self, wxID_OK, 'OK'), 0, wxALL, 3)
-            sz2.Add(wxButton(self, wxID_CANCEL, 'Cancel'), 0, wxALL, 3)
-            szr.Add(sz2, 0, wxALL|wxALIGN_CENTER, 3)
+            szr = wx.BoxSizer(wx.VERTICAL)
+            szr.Add(klass_prop.panel, 0, wx.EXPAND)
+            sz2 = wx.BoxSizer(wx.HORIZONTAL)
+            sz2.Add(wx.Button(self, wx.ID_OK, _('OK')), 0, wx.ALL, 3)
+            sz2.Add(wx.Button(self, wx.ID_CANCEL, _('Cancel')), 0, wx.ALL, 3)
+            szr.Add(sz2, 0, wx.ALL|wx.ALIGN_CENTER, 3)
             self.SetAutoLayout(True)
             self.SetSizer(szr)
             szr.Fit(self)
@@ -839,7 +856,7 @@ def builder(parent, sizer, pos, number=[0]):
     # end of inner class
 
     dialog = Dialog()
-    if dialog.ShowModal() == wxID_CANCEL:
+    if dialog.ShowModal() == wx.ID_CANCEL:
         # cancel the operation
         dialog.undo()
         dialog.Destroy()
